@@ -17,41 +17,25 @@ from dataclasses import dataclass
 from typing import List
 
 from dataclasses_json import LetterCase, dataclass_json
+from card_framework import standard_field
 
 from card_framework.v2.enums import HorizontalAlignment
 
 from .widget import Widget
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
-class InvalidWidget(Widget):
-  """Bad Widget, no override"""
-
-
-@dataclass_json(letter_case=LetterCase.CAMEL)
+@dataclass_json
 @dataclass
 class ValidWidget(Widget):
   """Good Widget"""
-  camel_case_property: str = 'Inigo Montoya'
-
-  @property
-  def _widget_tag(self) -> str:
-    return 'widget'
+  camel_case_property: str = standard_field()
 
 
 class WidgetTest(unittest.TestCase):
-  def test_invalid_widget(self) -> None:
-    widget = InvalidWidget()
-    with self.assertRaises(NotImplementedError):
-      widget._widget_tag
-
-  def test_valid_widget(self) -> None:
-    widget = ValidWidget()
-    self.assertEqual(widget._widget_tag, 'widget')
 
   def test_valid_widget_render(self) -> None:
     widget = ValidWidget()
+    widget.camel_case_property = 'Inigo Montoya'
     self.assertDictEqual(
         widget.render(),
-        {'widget': {'camelCaseProperty': 'Inigo Montoya'}})
+        {'validWidget': {'camelCaseProperty': 'Inigo Montoya'}})
